
From: Paul Mackerras <paulus@samba.org>

When I tried Ben's patches to the powermac sound driver on my G5, I found
that it was taking enormous numbers of sound DMA transmit interrupts.  This
turned out to be because it was incorrectly configured as level-sensitive
instead of edge-sensitive, which in turn was because the code that parses
the interrupt tree that Open Firmware gives us was incorrectly assigning
another device the same irq number as the sound DMA transmit interrupt
(i.e.  1).

This patch fixes the problem, in a somewhat quick and dirty way for now,
but one which will work for all the machines we currently run on. 
Ultimately Ben and I want to do something more general and robust, but this
should go in for 2.6.12.

Signed-off-by: Paul Mackerras <paulus@samba.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/ppc64/kernel/prom.c |    4 ++++
 1 files changed, 4 insertions(+)

diff -puN arch/ppc64/kernel/prom.c~ppc64-fix-irq-parsing-on-powermac arch/ppc64/kernel/prom.c
--- 25/arch/ppc64/kernel/prom.c~ppc64-fix-irq-parsing-on-powermac	2005-04-25 22:55:13.311251232 -0700
+++ 25-akpm/arch/ppc64/kernel/prom.c	2005-04-25 22:55:13.316250472 -0700
@@ -321,6 +321,10 @@ static int __devinit finish_node_interru
 			char *name = get_property(ic->parent, "name", NULL);
 			if (name && !strcmp(name, "u3"))
 				np->intrs[intrcount].line += 128;
+			else if (!(name && !strcmp(name, "mac-io")))
+				/* ignore other cascaded controllers, such as
+				   the k2-sata-root */
+				break;
 		}
 		np->intrs[intrcount].sense = 1;
 		if (n > 1)
_
